@@ -23,6 +23,7 @@
 
 #include "types/translatablestring.h"
 
+#include "muse_framework_config.h"
 #include "log.h"
 
 using namespace mu;
@@ -112,15 +113,19 @@ void AppMenuModel::setupConnections()
     //     workspacesItem.setSubitems(makeWorkspacesItems());
     // });
 
-    // extensionsProvider()->manifestListChanged().onNotify(this, [this]() {
-    //     MenuItem& pluginsMenu = findMenu("menu-plugins");
-    //     pluginsMenu.setSubitems(makePluginsMenuSubitems());
-    // });
+    uiActionsRegister()->actionsChanged().onReceive(this, [this](const ui::UiActionList& acts) {
+        for (const UiAction& act : acts) {
+            MenuItem& item = findItem(act.code);
+            if (item.isValid()) {
+                item.setAction(act);
+            }
+        }
+    });
 
-    // extensionsProvider()->manifestChanged().onReceive(this, [this](const Manifest&) {
-    //     MenuItem& pluginsItem = findMenu("menu-plugins");
-    //     pluginsItem.setSubitems(makePluginsMenuSubitems());
-    // });
+    effectsProvider()->effectMetaListChanged().onNotify(this, [this]() {
+        MenuItem& effectsItem = findMenu("menu-effect");
+        effectsItem.setSubitems(makeEffectsItems());
+    });
 }
 
 MenuItem* AppMenuModel::makeMenuItem(const actions::ActionCode& actionCode, MenuItemRole menuRole)
@@ -179,10 +184,10 @@ MenuItem* AppMenuModel::makeEditMenu()
         makeMenuItem("paste"),
         makeMenuItem("delete"),
         makeSeparator(),
-        makeMenuItem("cut-and-close-gap"),
+        makeMenuItem("split-cut"),
         makeMenuItem("duplicate"),
         makeMenuItem("insert"),
-        makeMenuItem("delete-and-close-gap"),
+        makeMenuItem("split-delete"),
         makeSeparator(),
         makeMenu(TranslatableString("appshell/menu/clip", "Clip"), makeClipItems(), "menu-clip"),
         makeMenuItem("silence-audio"),
@@ -286,8 +291,6 @@ MenuItem* AppMenuModel::makeGenerateMenu()
     MenuItemList generateItems {
         makeMenuItem("generate-plugin-manager"),
         makeSeparator(),
-        makeMenuItem("repeat-last-generator"),
-        makeSeparator(),
         makeMenuItem("generate-omitted"),
     };
 
@@ -296,33 +299,7 @@ MenuItem* AppMenuModel::makeGenerateMenu()
 
 MenuItem* AppMenuModel::makeEffectMenu()
 {
-    MenuItemList effectItems {
-        makeMenuItem("effect-plugin-manager"),
-        makeMenuItem("add-realtime-effects"),
-        makeSeparator(),
-        makeMenuItem("repeat-last-effect"),
-        makeSeparator(),
-        makeMenuItem("favourite-effect-1"),
-        makeMenuItem("favourite-effect-2"),
-        makeMenuItem("favourite-effect-3"),
-        makeSeparator(),
-        //! TODO AU4 - expand effects
-        makeMenu(TranslatableString("appshell/menu/volumecomp", "Volume and compression"),
-                 makeVolumeAndCompressionItems(), "menu-volumecomp"),
-        makeMenu(TranslatableString("appshell/menu/fading", "Fading"), makeVolumeAndCompressionItems(), "menu-fading"),
-        makeMenu(TranslatableString("appshell/menu/pitchtempo", "Pitch and tempo"), makeVolumeAndCompressionItems(), "menu-pitchtempo"),
-        makeMenu(TranslatableString("appshell/menu/eq", "EQ & filters"), makeVolumeAndCompressionItems(), "menu-eq"),
-        makeMenu(TranslatableString("appshell/menu/noiserepair", "Noise removal & repair"),
-                 makeVolumeAndCompressionItems(), "menu-noiserepair"),
-        makeMenu(TranslatableString("appshell/menu/delayreverb", "Delay & reverb"), makeVolumeAndCompressionItems(), "menu-delayreverb"),
-        makeMenu(TranslatableString("appshell/menu/distmod", "Distortion & modulation"), makeVolumeAndCompressionItems(), "menu-distmod"),
-        makeMenu(TranslatableString("appshell/menu/special", "Special"), makeVolumeAndCompressionItems(), "menu-special"),
-        makeMenu(TranslatableString("appshell/menu/spectral", "Spectral tools"), makeVolumeAndCompressionItems(), "menu-spectral"),
-        makeSeparator(),
-        makeMenuItem("plugins-omitted")
-    };
-
-    return makeMenu(TranslatableString("appshell/menu/effect", "&Effect"), effectItems, "menu-effect");
+    return makeMenu(TranslatableString("appshell/menu/effect", "&Effect"), makeEffectsItems(), "menu-effect");
 }
 
 MenuItem* AppMenuModel::makeAnalyzeMenu()
@@ -330,8 +307,6 @@ MenuItem* AppMenuModel::makeAnalyzeMenu()
     MenuItemList analyzeItems {
         makeMenuItem("analyze-plugin-manager"),
         makeSeparator(),
-        makeMenuItem("repeat-last-analyzer"),
-        makeSeparator(),
         makeMenuItem("contrast-analyzer"),
         makeMenuItem("plot-spectrum"),
         makeMenuItem("analyzer-omitted"),
@@ -345,8 +320,6 @@ MenuItem* AppMenuModel::makeToolsMenu()
     MenuItemList toolsItems {
         makeMenuItem("tools-plugin-manager"),
         makeSeparator(),
-        makeMenuItem("repeat-last-tool"),
-        makeSeparator(),
         makeMenuItem("manage-macros"),
         makeMenu(TranslatableString("appshell/menu/macros", "&Macros"), makeMacrosItems(), "menu-macros"),
         makeSeparator(),
@@ -363,23 +336,6 @@ MenuItem* AppMenuModel::makeToolsMenu()
     return makeMenu(TranslatableString("appshell/menu/tools", "&Tools"), toolsItems, "menu-tools");
 }
 
-MenuItemList AppMenuModel::makePluginsMenuSubitems()
-{
-    MenuItemList subitems {
-        makeMenuItem("manage-plugins"),
-    };
-
-    MenuItemList enabledPlugins = makePluginsItems();
-
-    if (!enabledPlugins.empty()) {
-        subitems << makeSeparator();
-    }
-
-    subitems << enabledPlugins;
-
-    return subitems;
-}
-
 MenuItem* AppMenuModel::makeExtraMenu()
 {
     MenuItemList extraItems {
@@ -432,6 +388,8 @@ MenuItem* AppMenuModel::makeHelpMenu()
         makeMenuItem("updates"),
         makeMenuItem("about-audacity"),
         makeMenuItem("about-qt", MenuItemRole::AboutQtRole),
+        makeSeparator(),
+        makeMenuItem("revert-factory")
     };
 
     //! TODO AU4
@@ -499,10 +457,10 @@ MenuItemList AppMenuModel::makeClipItems()
         makeMenuItem("rename-clip"),
         makeMenuItem("trim-clip"),
         makeSeparator(),
-        makeMenuItem("split-clip"),
+        makeMenuItem("split"),
         makeMenuItem("split-into-new-track"),
         makeMenuItem("split-clips-at-silences"),
-        makeMenuItem("merge-selected-clips"),
+        makeMenuItem("join"),
         makeSeparator(),
         makeMenuItem("group-clips"),
         makeMenuItem("ungroup-clips")
@@ -621,18 +579,38 @@ MenuItemList AppMenuModel::makeMacrosItems()
 
 MenuItemList AppMenuModel::makeDiagnosticsItems()
 {
-    MenuItemList items {
-        makeMenuItem("device-info"),
-        makeMenuItem("midi-device-info"),
-        makeMenuItem("log"),
-        makeMenuItem("crash-report"),
-        makeMenuItem("raise-segfault"),
-        makeMenuItem("throw-exception"),
-        makeMenuItem("violate-assertion"),
-        makeMenuItem("menu-tree"),
-        makeMenuItem("frame-statistics")
+    MenuItemList systemItems {
+        makeMenuItem("diagnostic-show-paths"),
+        makeMenuItem("diagnostic-show-profiler"),
     };
 
+    MenuItemList items {
+        makeMenuItem("diagnostic-save-diagnostic-files"),
+        makeMenu(TranslatableString("appshell/menu/diagnostic", "&System"), systemItems, "menu-system")
+    };
+
+    if (globalConfiguration()->devModeEnabled()) {
+#ifdef MUSE_MODULE_ACCESSIBILITY
+        MenuItemList accessibilityItems {
+            makeMenuItem("diagnostic-show-navigation-tree"),
+            makeMenuItem("diagnostic-show-accessible-tree"),
+            makeMenuItem("diagnostic-accessible-tree-dump"),
+        };
+        items << makeMenu(TranslatableString("appshell/menu/diagnostic", "&Accessibility"), accessibilityItems, "menu-accessibility");
+#endif
+
+#ifdef MUSE_MODULE_AUTOBOT
+        MenuItemList autobotItems {
+            makeMenuItem("autobot-show-scripts"),
+        };
+        items << makeMenu(TranslatableString("appshell/menu/diagnostic", "Auto&bot"), autobotItems, "menu-autobot");
+#endif
+
+#ifdef MUSE_MODULE_MULTIINSTANCES
+        items << makeMenuItem("multiinstances-dev-show-info");
+#endif
+    }
+
     return items;
 }
 
@@ -704,55 +682,35 @@ MenuItemList AppMenuModel::makeShowItems()
     return items;
 }
 
-MenuItemList AppMenuModel::makePluginsItems()
+MenuItemList AppMenuModel::makeEffectsItems()
 {
-    MenuItemList result;
+    MenuItemList items {
+        makeMenuItem("effect-plugin-manager"),
+        makeMenuItem("add-realtime-effects"),
+        makeSeparator(),
+        makeMenuItem("repeat-last-effect"),
+        makeSeparator(),
+        makeMenuItem("favourite-effect-1"),
+        makeMenuItem("favourite-effect-2"),
+        makeMenuItem("favourite-effect-3"),
+        makeSeparator(),
+    };
 
-    //! TODO AU4
-    // KnownCategories categories = extensionsProvider()->knownCategories();
-    // ManifestList enabledExtensions = extensionsProvider()->manifestList(Filter::Enabled);
+    std::map<muse::String, MenuItemList> effectsToCategoryMap;
 
-    // auto addMenuItems = [this](MenuItemList& items, const Manifest& m) {
-    //     if (m.actions.size() == 1) {
-    //         const extensions::Action& a = m.actions.at(0);
-    //         items << makeMenuItem(makeUriQuery(m.uri, a.code).toString(), TranslatableString::untranslatable(a.title));
-    //     } else {
-    //         MenuItemList sub;
-    //         for (const extensions::Action& a : m.actions) {
-    //             sub << makeMenuItem(makeUriQuery(m.uri, a.code).toString(), TranslatableString::untranslatable(a.title));
-    //         }
-    //         items << makeMenu(TranslatableString::untranslatable(m.title), sub);
-    //     }
-    // };
+    effects::EffectMetaList metaList = effectsProvider()->effectMetaList();
 
-    // std::map<std::string, MenuItemList> categoriesMap;
-    // MenuItemList pluginsWithoutCategories;
-    // for (const Manifest& m : enabledExtensions) {
-    //     std::string categoryStr = m.category.toStdString();
-    //     if (muse::contains(categories, categoryStr)) {
-    //         MenuItemList& items = categoriesMap[categoryStr];
-    //         addMenuItems(items, m);
-    //     } else {
-    //         addMenuItems(pluginsWithoutCategories, m);
-    //     }
-    // }
+    for (const effects::EffectMeta& meta : metaList) {
+        MenuItem* item = makeMenuItem("effect-open", TranslatableString::untranslatable(meta.title));
+        item->setId(meta.id);
+        item->setArgs(ActionData::make_arg1<muse::String>(meta.id));
 
-    // for (const auto& it : categoriesMap) {
-    //     TranslatableString categoryTitle = muse::value(categories, it.first, {});
-    //     result << makeMenu(categoryTitle, it.second);
-    // }
+        effectsToCategoryMap[meta.categoryId].push_back(item);
+    }
 
-    // std::sort(result.begin(), result.end(), [](const MenuItem& l, const MenuItem& r) {
-    //     return l.translatedTitle() < r.translatedTitle();
-    // });
+    for (const effects::EffectCategory& category : effectsProvider()->effectsCategoryList()) {
+        items << makeMenu(TranslatableString::untranslatable(category.title), effectsToCategoryMap[category.id]);
+    }
 
-    // std::sort(pluginsWithoutCategories.begin(), pluginsWithoutCategories.end(), [](const MenuItem& l, const MenuItem& r) {
-    //     return l.translatedTitle() < r.translatedTitle();
-    // });
-
-    // for (MenuItem* plugin : pluginsWithoutCategories) {
-    //     result << plugin;
-    // }
-
-    return result;
+    return items;
 }
